| Title: | MSigDB Gene Sets for Multiple Organisms in a Tidy Data Format |
|---|---|
| Description: | Provides the 'Molecular Signatures Database' (MSigDB) gene sets typically used with the 'Gene Set Enrichment Analysis' (GSEA) software (Subramanian et al. 2005 <doi:10.1073/pnas.0506580102>, Liberzon et al. 2015 <doi:10.1016/j.cels.2015.12.004>, Castanza et al. 2023 <doi:10.1038/s41592-023-02014-7>) as an R data frame. The package includes the human genes as listed in MSigDB as well as the corresponding symbols and IDs for frequently studied model organisms such as mouse, rat, pig, fly, and yeast. |
| Authors: | Igor Dolgalev [aut, cre] (ORCID: <https://orcid.org/0000-0003-4451-126X>) |
| Maintainer: | Igor Dolgalev <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 26.1.0 |
| Built: | 2026-05-11 09:19:43 UTC |
| Source: | https://github.com/igordot/msigdbr |
Retrieve a data frame of gene sets and their member genes. The original human genes can be converted into their corresponding counterparts in various model organisms, including mouse, rat, pig, zebrafish, fly, and yeast. The output includes gene symbols along with NCBI and Ensembl IDs.
msigdbr( db_species = "HS", species = "human", collection = NULL, subcollection = NULL, category = deprecated(), subcategory = deprecated() )msigdbr( db_species = "HS", species = "human", collection = NULL, subcollection = NULL, category = deprecated(), subcategory = deprecated() )
db_species |
Species abbreviation for the human or mouse databases ( |
species |
Species name for output genes, such as |
collection |
Collection abbreviation, such as |
subcollection |
Sub-collection abbreviation, such as |
category |
|
subcategory |
Historically, the MSigDB resource has been tailored to the analysis of human-specific datasets, with gene sets exclusively aligned to the human genome. Starting with release 2022.1, MSigDB incorporated a database of mouse-native gene sets and was split into human and mouse divisions ("Hs" and "Mm"). Each one is provided in the approved gene symbols of its respective species.
Mouse MSigDB includes gene sets curated from mouse-centric datasets and specified in native mouse gene identifiers, eliminating the need for ortholog mapping.
A tibble (a data frame with class tibble::tbl_df) of gene sets with one gene per row.
https://www.gsea-msigdb.org/gsea/msigdb/index.jsp
# Get all human gene sets gs <- msigdbr() head(gs) # Get all mouse gene sets gs <- msigdbr(db_species = "MM", species = "Mus musculus") head(gs) # Get CGP (chemical and genetic perturbations) gene sets with genes mapped to rat orthologs gs <- msigdbr(species = "Rattus norvegicus", collection = "C2", subcollection = "CGP") head(gs)# Get all human gene sets gs <- msigdbr() head(gs) # Get all mouse gene sets gs <- msigdbr(db_species = "MM", species = "Mus musculus") head(gs) # Get CGP (chemical and genetic perturbations) gene sets with genes mapped to rat orthologs gs <- msigdbr(species = "Rattus norvegicus", collection = "C2", subcollection = "CGP") head(gs)
List the collections available in the msigdbr package
msigdbr_collections(db_species = "HS")msigdbr_collections(db_species = "HS")
db_species |
Species abbreviation for the human or mouse databases ( |
A data frame of the available collections.
msigdbr_collections()msigdbr_collections()
List the species available in the msigdbr package
msigdbr_species()msigdbr_species()
A data frame of the available species.
msigdbr_species()msigdbr_species()